import QtQuick 2.2
import QtQuick.Layouts 1.11
import QtQuick.Controls 2.15 as QQC2

import org.kde.kcm 1.3 as KCM
import org.kde.kirigami 2.19 as Kirigami
import org.kde.kirigamiaddons.labs.mobileform 0.1 as MobileForm
import org.kde.plasma.components 3.0 as PlasmaComponents3

import AfickAliasEditor 1.0

KCM.SimpleKCM {
    id: root
    Kirigami.Theme.colorSet: Kirigami.Theme.Window

    property var mainPage

    title: i18nc("@title", "Alias overview")

    actions {
        contextualActions: [
            Kirigami.Action {
                text: i18nc("@action:button", "Reset")
                enabled: kcm.needsSave
                onTriggered: kcm.loadConfig()
            },

            Kirigami.Action {
                text: i18nc("@action:button", "Save")
                enabled: kcm.needsSave
                onTriggered: root.mainPage.save()
            }
        ]
    }

    MobileForm.FormCard {
        Layout.fillWidth: true

        contentItem: ColumnLayout {
            MobileForm.FormCardHeader {
                title: i18n("Aliases")
            }

            MobileForm.FormSwitchDelegate {
                id: showFullAttrNames

                text: i18n("Show full name of attributes")
                checked: AfickAliasEditor.showFullNames

                onCheckedChanged: {
                    AfickAliasEditor.showFullNames = checked;
                }
            }

            MobileForm.AbstractFormDelegate {
                contentItem: ColumnLayout {
                    Layout.fillWidth: true
                    QQC2.Label {
                        text: i18n("Select the alias to edit")
                        bottomPadding: Kirigami.Units.largeSpacing
                    }
                    RowLayout {
                        QQC2.RoundButton {
                            icon.name: "list-add"
                            icon.height: implicitHeight - topPadding - bottomPadding
                            onClicked: AfickAliasEditor.currentAlias = "Alias" + Math.floor(10000 * Math.random())
                        }

                        AttrsListView {
                            id: aliasesView
                            Layout.alignment: Qt.AlignTop
                            model: AfickAliasEditor.aliases

                            onClicked: AfickAliasEditor.currentAlias = buttonText
                        }
                    }
                }
            }

            MobileForm.AbstractFormDelegate {
                id: currentAliasGroupBox
                Layout.fillWidth: true
                visible: false
                contentItem: ColumnLayout {
                    RowLayout {
                        QQC2.TextField {
                            id: currentAliasLabel
                            font.bold: true
                            text: AfickAliasEditor.currentAlias
                            validator: RegExpValidator { regExp: /[a-zA-Z0-9]{3,}/ }
                            onEditingFinished: {
                                AfickAliasEditor.renameCurrentAlias(text);
                            }
                            onTextChanged: {
                                currentAliasGroupBox.visible = true;
                            }
                        }

                        QQC2.Label {
                            text: " = "
                        }

                        AttrsListView {
                            model: AfickAliasEditor.aliasAttributes
                            hasCloseIcon: true

                            onClicked: {
                                AfickAliasEditor.removeAliasAttribute(buttonText);
                            }
                        }
                    }

                    AttrsListView {
                        model: AfickAliasEditor.unusedAliasAttributes

                        onClicked: {
                            AfickAliasEditor.addAliasAttribute(buttonText);
                        }
                    }
                }
            }

            MobileForm.FormDelegateSeparator {}

            AfickConfManualText {}
        }
    }
}
