import QtQuick 2.2
import QtQuick.Layouts 1.11
import QtQuick.Controls 2.15 as QQC2

import org.kde.kcm 1.3 as KCM
import org.kde.kirigami 2.19 as Kirigami
import org.kde.kirigamiaddons.labs.mobileform 0.1 as MobileForm

import AfickCurrentRule 1.0

KCM.SimpleKCM {
    id: root
    Kirigami.Theme.colorSet: Kirigami.Theme.Window

    property var mainPage

    title: AfickCurrentRule.path

    actions {
        contextualActions: [
            Kirigami.Action {
                text: i18nc("@action:button", "Reset")
                enabled: kcm.needsSave
                onTriggered: kcm.loadConfig()
            },

            Kirigami.Action {
                text: i18nc("@action:button", "Save")
                enabled: kcm.needsSave
                onTriggered: root.mainPage.save()
            }
        ]
    }

    MobileForm.FormCard {
        Layout.fillWidth: true

        contentItem: ColumnLayout {
            MobileForm.FormCardHeader {
                title: i18n("Selection type")
            }

            QQC2.ButtonGroup {
                id: prefixButtonGroup
                exclusive: true
                buttons: prefixLayout.children
            }
            ColumnLayout {
                id: prefixLayout
                spacing: 0

                MobileForm.FormRadioDelegate {
                    id: defaultPrefixItem
                    text: i18n("Files and sub-directories")
                    checked: AfickCurrentRule.prefix == ""
                    onClicked: {
                        AfickCurrentRule.prefix = "";
                    }
                }
                MobileForm.FormRadioDelegate {
                    id: notPrefixItem
                    text: i18n("The file or directory specified is ignored")
                    checked: AfickCurrentRule.prefix == "!"
                    onClicked: {
                        AfickCurrentRule.prefix = "!";
                    }
                }
                MobileForm.FormRadioDelegate {
                    id: avoidPrefixItem
                    text: i18n("Avoid sub-dir scan")
                    checked: AfickCurrentRule.prefix == "="
                    onClicked: {
                        AfickCurrentRule.prefix = "=";
                    }
                }
            }

            MobileForm.FormCardHeader {
                title: i18n("Attributes")
            }

            MobileForm.FormSwitchDelegate {
                id: showFullAttrNames

                text: i18n("Show full name of attributes")
                checked: AfickCurrentRule.showFullNames

                onCheckedChanged: {
                    AfickCurrentRule.showFullNames = checked;
                }
            }

            MobileForm.AbstractFormDelegate {
                Layout.fillWidth: true
                contentItem: ColumnLayout {
                    QQC2.Label {
                        text: i18n("Applied attributes:")
                        bottomPadding: Kirigami.Units.largeSpacing
                    }

                    AttrsListView {
                        model: AfickCurrentRule.attributes
                        hasCloseIcon: true
                        onClicked: {
                            AfickCurrentRule.removeAttribute(buttonText);
                        }
                    }
                }
            }

            MobileForm.AbstractFormDelegate {
                Layout.fillWidth: true
                contentItem: ColumnLayout {
                    QQC2.Label {
                        text: i18n("Unapplied attributes:")
                        bottomPadding: Kirigami.Units.largeSpacing
                    }
                    AttrsListView {
                        model: AfickCurrentRule.unusedAttributes

                        onClicked: {
                            AfickCurrentRule.addAttribute(buttonText);
                        }
                    }
                }
            }

            MobileForm.FormDelegateSeparator {}

            AfickConfManualText {}
        }
    }
}
